/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/*****************************************************************************/
/** \file flash.h
**
** 
**
** History:
** 
*****************************************************************************/
#ifndef __FLASH_H__
#define __FLASH_H__
/*****************************************************************************/
/* Include files */
/*****************************************************************************/
#include "cms8s589xx.h"
/*****************************************************************************/
/* Global pre-processor symbols/macros ('#define') */
/*****************************************************************************/
/*----------------------------------------------------------------------------
 **FLASH 
/*---------------------------------------------------------------------------*/
#define	FLASH_APROM			(0x55)
#define	FLASH_DATA			(0xAA)
#define	FLASH_BOOT			(0x96)

/*----------------------------------------------------------------------------
 **FLASH 
/*---------------------------------------------------------------------------*/
#define	FLASH_WRITE			(0xAA)
#define	FLASH_READ			(0x69)
#define	FLASH_ERASE			(0x55)
#define	FLASH_CRC			(0x96)

/*****************************************************************************/
/* Global type definitions ('typedef') */
/*****************************************************************************/


/*****************************************************************************/
/* Global variable declarations ('extern', definition in C source) */
/*****************************************************************************/


/*****************************************************************************/
/* Global function prototypes ('extern', definition in C source) */
/*****************************************************************************/
/*****************************************************************************
 ** \brief	FLASH_UnLock
 **			
 ** \param [in] none
 ** \return  none
 ** \note	 
*****************************************************************************/
void FLASH_UnLock(void);
/*****************************************************************************
 ** \brief	FLASH_Lock
 **			
 ** \param [in] none
 ** \return  none
 ** \note	 
*****************************************************************************/
void FLASH_Lock(void);

/*****************************************************************************
 ** \brief	FLASH_Write
 **			д
 ** \param [in] FLASHModule	(1)FLASH_DATA: DATA
 **							  (2)FLASH_APROMAPROM
 **							  (3)FLASH_BOOT : BOOT
 **				Addr: 18bit	(1)DATA 0x00~0xFFF
 **							  (2)APROM0x00~0xFFFF
 **							  (3)BOOT0x00~0x3FFF  
 **				Data: 8bit
 ** \return  none
 ** \note	 
*****************************************************************************/
void FLASH_Write(uint8_t FLASHModule, uint32_t Addr, uint8_t Data);

/*****************************************************************************
 ** \brief	FLASH_Read
 **			
 ** \param [in] FLASHModule	(1)FLASH_DATA: DATA
 **							  (2)FLASH_APROMAPROM
 **							  (3)FLASH_BOOT : BOOT
 **				Addr: 18bit	(1)DATA 0x00~0xFFF
 **							  (2)APROM0x00~0xFFFF
 **							  (3)BOOT0x00~0x3FFF  
 ** \return  8bit Data
 ** \note	
*****************************************************************************/
uint8_t FLASH_Read(uint8_t FLASHModule, uint32_t Addr);

/*****************************************************************************
 ** \brief	FLASH_Erase
 **			
 ** \param [in] FLASHModule	(1)FLASH_DATA: DATA
 **							  (2)FLASH_APROMAPROM
 **							  (3)FLASH_BOOT : BOOT
 **				Addr: 18bit	(1)DATA 0x00~0xFFF
 **							  (2)APROM0x00~0xFFFF
 **							  (3)BOOT0x00~0x3FFF  
 ** \return  none
 ** \note	
*****************************************************************************/
void FLASH_Erase(uint8_t FLASHModule, uint32_t Addr);

/*****************************************************************************
 ** \brief	FLASH_Crc
 **			CRCУ
 ** \param [in] FLASHModule	(1)FLASH_DATA: DATA
 **							  (2)FLASH_APROMAPROM
 **							  (3)FLASH_BOOT : BOOT
 **				SAddr/EAddr: 18bit(1)DATA 0x00~0xFFF
**						  			(2)APROM0x00~0xFFFF
 **							 	    (3)BOOT0x00~0x3FFF  
 ** \return 16λУֵ
 ** \note	
*****************************************************************************/
uint16_t  FLASH_Crc(uint8_t FLASHModule, uint32_t SAddr, uint32_t EAddr);
/*****************************************************************************
 ** \brief	FLASH_ReadMLockFlag
 **			ȡMLCOK־λ
 ** \param [in] none
 ** \return  0ɲFLASH  1ɲFLASH
 ** \note	 
*****************************************************************************/
uint8_t  FLASH_ReadMLockFlag(void);

/*****************************************************************************
 ** \brief	FLASH_ReadErrorFlag
 **			ȡ־λ
 ** \param [in] none
 ** \return  0޴  1
 ** \note	 
*****************************************************************************/
uint8_t  FLASH_ReadErrorFlag(void);

#endif /* __FLASH_H__ */
